function data = read_data(imu_data,path)
% Function read_data: Reads IMU data into a struct and adds image file name
%                     for times when image is taken
%
% Input:  imu_data:   matrix with IMU data in format got from IMU.log
%         path:       path to the directory where images are stored
%
% Output: data:       array of structs with following fields:
%                     t = time tag
%                     ax = x-acceleration
%                     ay = y-acceleration
%                     az = z-acceleration
%                     wx = x-angular rate
%                     wy = y-angular rate
%                     wz = z-angular rate
%                     q  = quaternion (4x1 vector)
%                     im_file_name = image file name
%                                    (if image exist for that time tag, otherwise '')

N = size(imu_data,1);
zerostr = '0000';

for i = 1:N
    timestr = num2str(imu_data(i,1),'%3.2f');
    timestr = [timestr(1:end-3) timestr(end-1:end)];
    prefix = [path,'image',zerostr(1:end-length(timestr)+3)];
    file_name = [prefix,timestr,'.jpg'];
    try
        imread(file_name,'jpg');
        data(i) = struct('t',imu_data(i,1),'ax',imu_data(i,2),'ay',...
            imu_data(i,3),'az',imu_data(i,4),'wx',imu_data(i,5),'wy',...
            imu_data(i,6),'wz',imu_data(i,7),'q',imu_data(i,11:14)',...
            'im_file_name',file_name);
    catch ME
        data(i) = struct('t',imu_data(i,1),'ax',imu_data(i,2),'ay',...
            imu_data(i,3),'az',imu_data(i,4),'wx',imu_data(i,5),'wy',...
            imu_data(i,6),'wz',imu_data(i,7),'q',imu_data(i,11:14)',...
            'im_file_name','');
    end
end